@@ -22,6 +22,7 @@
 #define DT_CONTROL_JOBS_H
 
 #include <inttypes.h>
+#include <stddef.h>
 
 #define DT_CONTROL_DESCRIPTION_LEN 256
 // reserved workers
@@ -54,9 +55,10 @@ typedef struct _dt_job_t dt_job_t;
 
 typedef int32_t (*dt_job_execute_callback)(dt_job_t *);
 typedef void (*dt_job_state_change_callback)(dt_job_t *, dt_job_state_t state);
+typedef void (*dt_job_destroy_callback)(void *data);
 
 /** create a new initialized job */
-dt_job_t *dt_control_job_create(dt_job_execute_callback execute, const char *msg, ...);
+dt_job_t *dt_control_job_create(dt_job_execute_callback execute, const char *msg, ...) __attribute__((format(printf, 2, 3)));
 /** destroy a job object and free its memory. this does NOT remove it from any job queues! */
 void dt_control_job_dispose(dt_job_t *job);
 /** setup a state callback for job. */
@@ -66,8 +68,13 @@ void dt_control_job_cancel(dt_job_t *job);
 dt_job_state_t dt_control_job_get_state(dt_job_t *job);
 /** wait for a job to finish execution. */
 void dt_control_job_wait(dt_job_t *job);
-/** accessors for internal fields */
-void dt_control_job_set_params(dt_job_t *job, void *params);
+/** set job params and a callback to destroy those params */
+void dt_control_job_set_params(dt_job_t *job, void *params, dt_job_destroy_callback callback);
+/** set job params (with size params_size) and a callback to destroy those params.
+  * NOTE: in most cases you want dt_control_job_set_params() */
+void dt_control_job_set_params_with_size(dt_job_t *job, void *params, size_t params_size,
+                                         dt_job_destroy_callback callback);
+/** get job params. WARNING: you must not free them. dt_control_job_dispose() will take care of that */
 void *dt_control_job_get_params(const dt_job_t *job);
 
 struct dt_control_t;
