@@ -41,7 +41,12 @@ public:
   string make;
   string model;
   string mode;
+  string canonical_make;
+  string canonical_model;
+  string canonical_alias;
+  string canonical_id;
   vector<string> aliases;
+  vector<string> canonical_aliases;
   ColorFilterArray cfa;
   bool supported;
   iPoint2D cropSize;
@@ -54,6 +59,7 @@ protected:
   void parseCFA( pugi::xml_node &node );
   void parseAlias( pugi::xml_node &node );
   void parseHint( pugi::xml_node &node );
+  void parseID( pugi::xml_node &node );
   void parseBlackAreas( pugi::xml_node &node );
   void parseSensorInfo( pugi::xml_node &node );
   vector<int> MultipleStringToInt(const char *in, const char *tag, const char* attribute);
