@@ -46,19 +46,20 @@ const uint32 datashifts[] = {0,0,0,1,2,3,0,0,1,2, 3, 2, 3, 2};
  * Note: RATIONALs are the ratio of two 32-bit integer values.
  */
 typedef	enum {
-	TIFF_NOTYPE	= 0,	/* placeholder */
-	TIFF_BYTE	= 1,	/* 8-bit unsigned integer */
-	TIFF_ASCII	= 2,	/* 8-bit bytes w/ last byte null */
-	TIFF_SHORT	= 3,	/* 16-bit unsigned integer */
-	TIFF_LONG	= 4,	/* 32-bit unsigned integer */
-	TIFF_RATIONAL	= 5,	/* 64-bit unsigned fraction */
-	TIFF_SBYTE	= 6,	/* !8-bit signed integer */
-	TIFF_UNDEFINED	= 7,	/* !8-bit untyped data */
-	TIFF_SSHORT	= 8,	/* !16-bit signed integer */
-	TIFF_SLONG	= 9,	/* !32-bit signed integer */
-	TIFF_SRATIONAL	= 10,	/* !64-bit signed fraction */
-	TIFF_FLOAT	= 11,	/* !32-bit IEEE floating point */
-	TIFF_DOUBLE	= 12	/* !64-bit IEEE floating point */
+  TIFF_NOTYPE    = 0, /* placeholder */
+  TIFF_BYTE      = 1, /* 8-bit unsigned integer */
+  TIFF_ASCII     = 2, /* 8-bit bytes w/ last byte null */
+  TIFF_SHORT     = 3, /* 16-bit unsigned integer */
+  TIFF_LONG      = 4, /* 32-bit unsigned integer */
+  TIFF_RATIONAL  = 5, /* 64-bit unsigned fraction */
+  TIFF_SBYTE     = 6, /* !8-bit signed integer */
+  TIFF_UNDEFINED = 7, /* !8-bit untyped data */
+  TIFF_SSHORT    = 8, /* !16-bit signed integer */
+  TIFF_SLONG     = 9, /* !32-bit signed integer */
+  TIFF_SRATIONAL = 10, /* !64-bit signed fraction */
+  TIFF_FLOAT     = 11, /* !32-bit IEEE floating point */
+  TIFF_DOUBLE    = 12, /* !64-bit IEEE floating point */
+  TIFF_OFFSET    = 13, /* 32-bit unsigned offset used in ORF at least */
 } TiffDataType;
 
 
