@@ -411,11 +411,19 @@ static gboolean _lib_filmstrip_size_handle_button_callback(GtkWidget *w, GdkEven
     if(e->type == GDK_BUTTON_PRESS)
     {
       /* store current  mousepointer position */
+#if GTK_CHECK_VERSION(3, 20, 0)
+      gdk_window_get_device_position(e->window,
+                                     gdk_seat_get_pointer(gdk_display_get_default_seat(gdk_window_get_display(
+                                         gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui))))),
+                                     &d->size_handle_x, &d->size_handle_y, 0);
+#else
       gdk_window_get_device_position(
           gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui)),
           gdk_device_manager_get_client_pointer(gdk_display_get_device_manager(
               gdk_window_get_display(gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui))))),
           &d->size_handle_x, &d->size_handle_y, NULL);
+#endif
+
       gtk_widget_get_size_request(d->filmstrip, NULL, &d->size_handle_height);
       d->size_handle_is_dragging = TRUE;
     }
@@ -433,11 +441,19 @@ static gboolean _lib_filmstrip_size_handle_motion_notify_callback(GtkWidget *w,
   if(d->size_handle_is_dragging)
   {
     gint x, y, sx, sy;
+#if GTK_CHECK_VERSION(3, 20, 0)
+    gdk_window_get_device_position(e->window,
+                                   gdk_seat_get_pointer(gdk_display_get_default_seat(gdk_window_get_display(
+                                       gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui))))),
+                                   &x, &y, 0);
+#else
     gdk_window_get_device_position(
         gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui)),
         gdk_device_manager_get_client_pointer(gdk_display_get_device_manager(
             gdk_window_get_display(gtk_widget_get_window(dt_ui_main_window(darktable.gui->ui))))),
         &x, &y, NULL);
+#endif
+
     gtk_widget_get_size_request(d->filmstrip, &sx, &sy);
     sy = CLAMP(d->size_handle_height + (d->size_handle_y - y), DT_PIXEL_APPLY_DPI(64),
                DT_PIXEL_APPLY_DPI(400));
